# Changelog

## [0.9.0](https://github.com/bhklab/bhklab-project-template/compare/v0.8.0...v0.9.0) (2025-05-20)


### Features

* add data directory audit workflow to check for committed data files ([#5](https://github.com/bhklab/bhklab-project-template/issues/5)) ([c60e45c](https://github.com/bhklab/bhklab-project-template/commit/c60e45c301ede72613efe38a8012dd15eafb0e17))
* Add pypi-dependencies section and update example notebook and script to use `dirs` object ([#24](https://github.com/bhklab/bhklab-project-template/issues/24)) ([1d897ac](https://github.com/bhklab/bhklab-project-template/commit/1d897ac6ddd5875f8bc7725817d1556e30615928))


### Documentation

* Enhance documentation with new sections and troubleshooting guide ([dafdcac](https://github.com/bhklab/bhklab-project-template/commit/dafdcaceb52ebcd250125056c026047d803bd8ef))
* Update README to include usage instructions for `uv` and `copier` ([7127124](https://github.com/bhklab/bhklab-project-template/commit/7127124446155aca03de772d3f3fd97cbfbf5bfb))

## [0.8.0](https://github.com/bhklab/bhklab-project-template/compare/v0.7.0...v0.8.0) (2025-05-20)


### Features

* Add environment variables and example usage scripts ([#8](https://github.com/bhklab/bhklab-project-template/issues/8)) ([78758d1](https://github.com/bhklab/bhklab-project-template/commit/78758d10e2aa3d08ef966b7d3fa17326bdb8d391))

## [0.7.0](https://github.com/bhklab/bhklab-project-template/compare/v0.6.0...v0.7.0) (2025-05-12)


### Features

* dont hatch configure ([720632e](https://github.com/bhklab/bhklab-project-template/commit/720632e04f4053e6bee81877e179a9dd75df2da3))

## [0.6.0](https://github.com/bhklab/bhklab-project-template/compare/v0.5.6...v0.6.0) (2025-05-12)


### Features

* update build to hatch ([2067a86](https://github.com/bhklab/bhklab-project-template/commit/2067a8628d95f0726b5756e33ddc6183b2953892))

## [0.5.6](https://github.com/bhklab/bhklab-project-template/compare/v0.5.5...v0.5.6) (2025-05-12)


### Bug Fixes

* update dependency name in pixi.toml to use hyphen instead of underscore ([38e9c85](https://github.com/bhklab/bhklab-project-template/commit/38e9c85ffb9ed2e926271be67ebe9583f8d844b8))

## [0.5.5](https://github.com/bhklab/bhklab-project-template/compare/v0.5.4...v0.5.5) (2025-05-12)


### Bug Fixes

* correct script name in pyproject.toml ([6a164ec](https://github.com/bhklab/bhklab-project-template/commit/6a164ec2fcd96dc0ae993af5fa5c64d4fdfd6b9a))

## [0.5.4](https://github.com/bhklab/bhklab-project-template/compare/v0.5.3...v0.5.4) (2025-05-12)


### Bug Fixes

* add wheel and sdist targets to build configuration ([3868184](https://github.com/bhklab/bhklab-project-template/commit/3868184be8cc23c9fe0ed574ff843764184fbe4f))
* update sha256 checksum and add LICENSE file ([fa33b17](https://github.com/bhklab/bhklab-project-template/commit/fa33b1747488a4209bed446d253fea4f30815f71))

## [0.5.3](https://github.com/bhklab/bhklab-project-template/compare/v0.5.2...v0.5.3) (2025-05-12)


### Bug Fixes

* add id-token permission for GitHub Actions ([66a91e1](https://github.com/bhklab/bhklab-project-template/commit/66a91e13b2c72f4381ded61f24e88da622ddf4f1))
* correct indentation and streamline publish-pypi job steps ([5e9cacd](https://github.com/bhklab/bhklab-project-template/commit/5e9cacd137e6a46ac8ae712b785cce1b123dd569))
* update project metadata and add type hinting support ([5a6649d](https://github.com/bhklab/bhklab-project-template/commit/5a6649da2696c8fff9a8f6331ba99389f254f6b4))
* update project version to 0.5.2 and sha256 checksum ([defd4c3](https://github.com/bhklab/bhklab-project-template/commit/defd4c3eecb4a051b3be1977b4b43fcbfab69a10))

## [0.5.2](https://github.com/bhklab/bhklab-project-template/compare/v0.5.1...v0.5.2) (2025-05-12)


### Bug Fixes

* dont lock ([2832d1c](https://github.com/bhklab/bhklab-project-template/commit/2832d1ced3268f962e6a43ff4fb6d69fca1a47b7))

## [0.5.1](https://github.com/bhklab/bhklab-project-template/compare/v0.5.0...v0.5.1) (2025-05-12)


### Bug Fixes

* move default ([f932f8c](https://github.com/bhklab/bhklab-project-template/commit/f932f8c04d134e903474c948beb2404ec721652d))

## [0.5.0](https://github.com/bhklab/bhklab-project-template/compare/v0.4.0...v0.5.0) (2025-05-12)


### Features

* Add BHKLab project template CLI tool ([#12](https://github.com/bhklab/bhklab-project-template/issues/12)) ([4209392](https://github.com/bhklab/bhklab-project-template/commit/4209392626923eb0147de6013367cebc1321e2e0))
* Add lockfile update step in release workflow ([daece9c](https://github.com/bhklab/bhklab-project-template/commit/daece9c356b5063c0ed183345d831caef5e54d96))

## [0.4.0](https://github.com/bhklab/bhklab-project-template/compare/v0.3.1...v0.4.0) (2025-05-10)


### Features

* update project_name and project_description placeholders for dynamic values ([ca80e5f](https://github.com/bhklab/bhklab-project-template/commit/ca80e5ff457e44a951589b8da5e72147883f2821))

## [0.3.1](https://github.com/bhklab/bhklab-project-template/compare/v0.3.0...v0.3.1) (2025-05-10)


### Bug Fixes

* ascii art ([3ca1013](https://github.com/bhklab/bhklab-project-template/commit/3ca1013311614640fa9dae48c482cf8c1f72009d))

## [0.3.0](https://github.com/bhklab/bhklab-project-template/compare/v0.2.0...v0.3.0) (2025-05-09)


### Features

* add release command for initial alpha version in project setup ([6988526](https://github.com/bhklab/bhklab-project-template/commit/6988526be15970a69d0d19612b9796963f5d3164))

## [0.2.0](https://github.com/bhklab/bhklab-project-template/compare/v0.1.0...v0.2.0) (2025-05-09)


### Features

* add support for multiple authors in project templates ([47e3ae8](https://github.com/bhklab/bhklab-project-template/commit/47e3ae847bfe41e025b7603ef6cb02fdd0ca8a33))
* enhance project generator messages and structure setup tasks ([f83c0cd](https://github.com/bhklab/bhklab-project-template/commit/f83c0cde76221e183797cab03509c34f8c18cfb9))
